@@ -47,9 +47,9 @@
 
 #include "config.h"
 
-std::wstring        ossoVersion;
+std::wstring             ossoVersion;
 
-static Lum::AppInfo info;
+static Lum::Def::AppInfo info;
 
 class PackageFormatProvider : public Lum::TableView::FormatProvider
 {
